@@ -5,13 +5,13 @@ def _paras(**kwargs):
     """
     para = {
         # Internal gain module
-        "Int_in": 3, "Int_h": 12, "Int_out": 1,
+        "Int_in": 3, "Int_h": 8, "Int_out": 1,
 
         # External disturbance module
-        "Ext_in": 1, "Ext_h": 10, "Ext_out": 1,
+        "Ext_in": 2, "Ext_h": 16, "Ext_out": 1,
 
         # Zone module
-        "Zone_in": 1, "Zone_out": 1,
+        "Zone_in": 1, "Zone_h": 12, "Zone_out": 1,
 
         # HVAC module
         "HVAC_in": 1, "HVAC_out": 1,
@@ -22,14 +22,16 @@ def _paras(**kwargs):
         # LSTM baseline
         "LSTM_h" : 24,
 
-        "en_policy_in":3, "en_policy_hidden":24, "en_policy_out":1,
-        "de_policy_in":6, "de_policy_hidden":24, "de_policy_out":1,
+        "current_meas_dim": 7,
+        "future_disturbance_dim": 6,
+        "horizon": 96,
+        "hidden_dim": 256,
         "policy_epochs":200, "policy_lr":0.01,
 
         # Training hyperparameters
         "lr": 0.01,
-        "epochs": 30,
-        "patience": 3, #Early stop
+        "epochs": 100,
+        "patience": 5, #Early stop
     }
 
     # Allow override from kwargs
@@ -76,7 +78,9 @@ def _args(**kwargs):
         # "datapath": "/home/zjiang19/Documents/GitHub/Eplus_ModNN_Compare/dataset/Eplus/EPlus_train_AC_off_2month.csv", #"../Dataset/EPlus.csv",
         # "datapath": "/home/zjiang19/Documents/GitHub/Eplus_ModNN_Compare/dataset/Eplus/EPlus_train_case1.csv",
         # "datapath": "/home/zjiang19/Documents/GitHub/Physical-Incorporated-Neural-Network-BEM/update/403_new_dyn.csv",
-        "datapath": "/home/zjiang19/Documents/GitHub/ModNN-RL-403/dataset/Data_Process/data_coe_update.csv",
+        # "datapath": "/home/zjiang19/Documents/GitHub/ModNN-RL-403/dataset/Data_Process/data_coe_update.csv",
+        # "datapath":"/home/zjiang19/Documents/GitHub/BEST_OPT/dataset/dataset_1.csv",
+        "datapath": "/home/zjiang19/Documents/GitHub/BEST_OPT/bestopt/data/SFH/BLDG/clean/SFH_1.csv",
         "device": "cuda:1",
         "save_name": "Eplus",
 
@@ -86,8 +90,8 @@ def _args(**kwargs):
         "resolution": 15, # 15 minutes data
         "enLen": 48, # "Kind of warm-up"
         "deLen": 96, # Prediction horizon, 96 is for 24 hours
-        "startday": 390, # Training data selection
-        "trainday": 90, # Training data selection
+        "startday": 10, # Training data selection
+        "trainday": 180, # Training data selection
         "testday": 1, # Testing data selection
         "training_batch": 1024*1,
         "multi_deLen": [4, 8, 16, 24, 32, 48],
@@ -96,11 +100,11 @@ def _args(**kwargs):
         "ext_mdl": "RNN", # We provide LSTM and RNN module, for RNN, we can apply positive constraint easily
                            # But LSTM has Hadamard product, making this constraint hard to integrate
                            # However, disturbance variables always have similiar distribution, in other word, is this constraint really necessary?
-        "plott": '-all', # all: If want to see how model response to max heating/cooling; else: only Tzone prediction
+        "plott": 'all', # all: If want to see how model response to max heating/cooling; else: only Tzone prediction
         "modeltype": 'PI-modnn', # We also have "LSTM", "PI-modnn", "PI-modnn|C", "PI-modnn|L", "PI-modnn|LC" for fun
                                  # LSTM is the baseline, |C means no constraints, |L means no loss adjustment
         "scale": 1, # scaling factor for HVAC power
-        "temp_unit": "F",
+        "temp_unit": "C",
         "scaler_save_name": "ModNN_scaler.pkl", # scaler name you want to save
         "scaler_load": None, # load previous scaler
         "user_defined_minmax": # user defined minmax for data scaling
