@@ -17,6 +17,20 @@ class zone(nn.Module):
     def forward(self, x):
         return self.scale(x)
 
+# --- Zone Module ---
+# class zone(nn.Module):
+#     def __init__(self, input_size, hidden_size, output_size, num_layers=1):
+#         super(zone, self).__init__()
+#         self.dym = nn.RNN(input_size=input_size, hidden_size=hidden_size,
+#                                           num_layers=num_layers, batch_first=True, bias=True)
+#         self.fc = nn.Linear(hidden_size, output_size)
+#
+#     def forward(self, deltaq, hidden):
+#         Tpred, hidden = self.dym(deltaq, hidden)
+#         out = self.fc(Tpred)
+#
+#         return out, hidden
+
 # --- Internal Gain Module ---
 class internal(nn.Module):
     """
@@ -165,8 +179,9 @@ class external(nn.Module):
         self.hidden_size = hidden_size
 
     def forward(self, x_input, hidden_state):
-        ext_mdl_out, hidden = self.ext_mdl((x_input[:, :, [1]] - x_input[:, :, [0]]), hidden_state)
-        # ext_mdl_out, hidden = self.ext_mdl((x_input[:, :, [0,1]]), hidden_state)
+        # Need more work to explore weather we input the deltaT or just Tamb and Tspace toghether
+        # ext_mdl_out, hidden = self.ext_mdl((x_input[:, :, [1]] - x_input[:, :, [0]]), hidden_state)
+        ext_mdl_out, hidden = self.ext_mdl((x_input[:, :, [0,1]]), hidden_state)
         last_output = ext_mdl_out[:, -1:, :]
         out = self.relu(self.fc1(last_output))
         out = self.fc2(out)
@@ -177,6 +192,29 @@ class external(nn.Module):
 
         return out, hidden+solargain.permute(1, 0, 2)
 
+class external_CNN(nn.Module):
+    """
+    CNN-based External Module to learn heat gain from T_zone, T_ambient, and Solar radiation.
+    Models thermal lag with a convolution kernel of 6 hours (24 time steps).
+    """
+
+    def __init__(self, input_channels=3, kernel_size=24):
+        super(external_CNN, self).__init__()
+        self.conv1 = nn.Conv1d(in_channels=input_channels, out_channels=8,
+                               kernel_size=kernel_size, padding=0, bias=False)
+        self.relu = nn.ReLU()
+        self.conv2 = nn.Conv1d(in_channels=8, out_channels=1, kernel_size=1, padding=0, bias=False)
+        self.fc = nn.Linear(1, 1)
+
+    def forward(self, x_input, hidden_state=None):
+        # Input: (batch, window, features) → select 3 features and permute
+        x = x_input[:, :, [0, 1, 2]].permute(0, 2, 1)  # → (B, 3, T)
+        out = self.relu(self.conv1(x))  # → (B, 8, T - k + 1)
+        out = self.relu(self.conv2(out))  # → (B, 1, T - k + 1)
+        out = out[:, :, -1:]  # → take last time step → (B, 1, 1)
+        return self.fc(out.transpose(1, 2)), None  # → (B, 1, 1)
+
+
 # --- Modular Physics-Informed Neural Network ---
 class ModNN(nn.Module):
     """
@@ -189,10 +227,11 @@ class ModNN(nn.Module):
         self.device  = args['device']
         self.window  = para["window"]
         self.ext_mdl = args["ext_mdl"]
-
+        # self.Ext = external_CNN(input_channels=3, kernel_size=para["window"])
         self.Ext = external(para["Ext_in"], para["Ext_h"], para["Ext_out"], self.ext_mdl, para["window"])
         self.Zone = zone(para["Zone_in"], para["Zone_out"])
         self.HVAC = hvac(para["HVAC_in"], para["HVAC_out"])
+        # self.Zone = zone(para["Zone_in"], para["Zone_h"], para["Zone_out"])
         self.Int = internal(para["Int_in"], para["Int_h"], para["Int_out"])
 
     def forward(self, input_X):
@@ -216,6 +255,8 @@ class ModNN(nn.Module):
         else:
             ext_hidd = torch.ones(1, Ext_X.shape[0], self.Ext.ext_mdl.hidden_size).to(self.device)
             ext_cell = torch.ones(1, Ext_X.shape[0], self.Ext.ext_mdl.hidden_size).to(self.device)
+
+        # zone_hidd = torch.ones(1, input_X.shape[0], self.Zone.dym.hidden_size).to(self.device)
         # This is the look back window
         # I strongly suggest to use it, if you are using MLP external module
         # The value if how long you want to look back, typically, larger value for heavy structures
@@ -248,6 +289,7 @@ class ModNN(nn.Module):
                 input_X[:, i-window_size+1:i+1, [0]] * ratio + TOut_list[:, i-window_size+1:i+1, :] * (1 - ratio),
                 Ext_X[:, i-window_size+1:i+1, :]
             ], dim=2)
+            # ext_flux, _ = self.Ext(ext_embed, None)
             if self.ext_mdl == "RNN" or self.ext_mdl == "GRU":
                 ext_flux, ext_hidd = self.Ext(ext_embed, ext_hidd)
             else:
@@ -258,14 +300,17 @@ class ModNN(nn.Module):
             # For a well controlled space, it's not important
             # But if you are interested in extreme case, please add Tzone for Int input
             int_flux = self.Int(Int_X[:, i:i+1, :])
-            total_flux = ext_flux + hvac_flux + int_flux
+            total_flux = ext_flux  + int_flux+ hvac_flux
             HVAC_list[:, i, :] = hvac_flux.squeeze(1)
             Ext_list[:, i, :] = ext_flux.squeeze(1)
             Int_list[:, i, :] = int_flux.squeeze(1)
             deltaQ_list[:, i, :] = total_flux.squeeze(1)
 
             # After get total flux, we can predict the ΔTzone, and use residual connection to predict Tzone step by step
-            E_Zone_T =  input_X[:, i:i+1, [0]] + self.Zone(total_flux)
+            # E_Zone_T =  input_X[:, i:i+1, [0]] + self.Zone(total_flux)
+            # deltaT, zone_hidd = self.Zone(total_flux, zone_hidd)
+            deltaT = self.Zone(total_flux)
+            E_Zone_T =  input_X[:, i:i+1, [0]] + deltaT
 
         # --- Decoding Phase ---
         # Just transfer encoder module here
@@ -281,16 +326,21 @@ class ModNN(nn.Module):
             else:
                 ext_flux, (ext_hidd, ext_cell) = self.Ext(ext_embed, (ext_hidd, ext_cell))
 
+            # ext_flux, _ = self.Ext(ext_embed, None)
             hvac_flux = self.HVAC(HVAC_X[:, i:i+1, :])
             int_flux = self.Int(Int_X[:, i:i+1, :])
-            total_flux = ext_flux + hvac_flux + int_flux
+            total_flux = ext_flux  + int_flux+ hvac_flux
 
             HVAC_list[:, i, :] = hvac_flux.squeeze(1)
             Ext_list[:, i, :] = ext_flux.squeeze(1)
             Int_list[:, i, :] = int_flux.squeeze(1)
             deltaQ_list[:, i, :] = total_flux.squeeze(1)
             # No self-learning during decoder stage
-            E_Zone_T = E_Zone_T + self.Zone(total_flux)
+            # E_Zone_T = E_Zone_T + self.Zone(total_flux)
+            # deltaT, zone_hidd = self.Zone(total_flux, zone_hidd)
+            deltaT = self.Zone(total_flux)
+            E_Zone_T = E_Zone_T + deltaT
+
 
         # Return not only temperature, but also latent flux
         # Not sure how to use these fluxes right now, but leave for placeholder
@@ -310,6 +360,7 @@ class ModNN_step(nn.Module):
 
         self.Ext = external(para["Ext_in"], para["Ext_h"], para["Ext_out"], self.ext_mdl, para["window"])
         self.Zone = zone(para["Zone_in"], para["Zone_out"])
+        # self.Zone = zone(para["Zone_in"], para["Zone_h"], para["Zone_out"])
         self.HVAC = hvac(para["HVAC_in"], para["HVAC_out"])
         self.Int = internal(para["Int_in"], para["Int_h"], para["Int_out"])
 
