@@ -144,13 +144,16 @@ def train_model(model, train_loader, valid_loader, test_loader, lr, epochs,
                         try:
                             # Positive Hard Constraints
                             model.Zone.scale.weight.data.clamp_(0)
+                            # model.Zone.dym.weight_ih_l0.data.clamp_(0)
+                            # model.Zone.dym.weight_hh_l0.data.clamp_(0)
+                            # model.Zone.fc.weight.data.clamp_(0)
                             model.Int.scale.weight.data.clamp_(0)
                             model.HVAC.scale.weight.data.clamp_(0)
 
-
                             # model.Ext.conduction.weight.data.clamp_(0)
                             if ext_mdl == 'RNN':
-                                model.Ext.rnn.weight.data.clamp_(0)
+                                model.Ext.rnn.weight_ih_l0.data.clamp_(0)
+                                model.Ext.rnn.weight_hh_l0.data.clamp_(0)
                             else:
                                 pass
                         except:
@@ -255,7 +258,7 @@ def train_model(model, train_loader, valid_loader, test_loader, lr, epochs,
                     tem = Temp_out_denorm[timestep][:test_len - timestep]
                     ax.plot_date(rawdf.index[timestep:timestep + pred_len][:test_len - timestep],
                                      tem, '-', linewidth=1, color="gray", label=name)
-                    ax.set_ylim(meas.min()-1, meas.max()+1)
+                    # ax.set_ylim(meas.min()-1, meas.max()+1)
                     # for timestep in [24, 48, 72]:
                     #     tem_other = Temp_out_denorm[timestep][:test_len - timestep]
                     #     tem_other = (tem_other - 32) * 5 / 9
@@ -609,7 +612,7 @@ def control_model(dynamic_mdl, control_mdl, control_loader, args, test_loader, h
                 u_denorm = (u_opt - range_min) / (range_max - range_min) * (data_max - data_min) + data_min
                 price = torch.sum(torch.square(u_denorm/1000*data[:, args['enLen']-1:-1, [9]]))
 
-                to_loss = price*10 + vio
+                to_loss = price + vio*10
                 to_loss.backward()
                 optimizer.step()
 
@@ -618,7 +621,7 @@ def control_model(dynamic_mdl, control_mdl, control_loader, args, test_loader, h
                 price_loss += price.item() * data.size(0)
 
             control_mdl.eval()
-            res = 20
+            res = 10
             if epoch % res == 0:
                 with torch.no_grad():  # No gradients needed
                     for data, _ in test_loader:
